@@ -8,8 +8,9 @@ use std::{
 use anyhow::{anyhow, Context as AnyhowContext, Result};
 use bytesize::ByteSize;
 use git_repository::{
+    easy::object,
     hash::ObjectId,
-    object, odb,
+    odb,
     odb::{pack, pack::index},
     progress, Progress,
 };
